componenttools.copy_components_and_fracture_crossing_spanners
=============================================================

.. autofunction:: abjad.tools.componenttools.copy_components_and_fracture_crossing_spanners.copy_components_and_fracture_crossing_spanners
